
#include <unistd.h>
#include <getopt.h>
#include <libintl.h>
#include <locale.h>

#include "panacmds.h"


// common options for all commands
//
void display_common_usage()
{
  cout  << gettext("common options:")
<< endl << gettext("   -v level : sets verbose level, 0 for nothing.")
<< endl << gettext("   -w, --warning : consider warnings to be errors and abort command.")
<< endl;
}


// panalist usage
//
void display_panalist_usage()
{
  cout  << gettext("usage:")
<< endl << gettext("   panalist {-h --help}")
<< endl << gettext("   panalist [OPTIONS] pathname1 ... pathnameN")
<< endl << gettext("   panalist [OPTIONS]")
<< endl
<< endl << gettext("options:")
<< endl << gettext("   -r, --recursive : recursive listing of directories")
<< endl << gettext("   -l, --long : shows base, fragments and hash for file")
<< endl << gettext("   -t, --time-stamp : shows time-stamp of file")
<< endl << gettext("   -c, --compare-file file : compare this file with listed ones")
<< endl << gettext("   -g, --cluster : shows files grouped by base")
<< endl << endl;
display_common_usage();
}


// panalist command
//
int main( int argc, char **argv)
{
	int options = 0;
	char * compare = 0;


	// language initialization
	//
	setlocale( LC_MESSAGES, "");
	bindtextdomain( PACKAGE, PACKAGE_ROOT_DIRECTORY);
	textdomain( PACKAGE);


	// Process command-line options
	//
	while (1)
	{
		int short_option;	// Short option character

		// Long options declaration & short options mappings
		//
		static struct option long_options[] =
		{
			{ "recursive", 0, NULL, 'r' },
			{ "long", 0, NULL, 'l' },
			{ "time-stamp", 0, NULL, 't' },
			{ "compare-file", 1, NULL, 'c' },
			{ "cluster", 0, NULL, 'g' },
			{ "warn", 0, NULL, 'w' },
			{ "help", 0, NULL, 'h' },
			{ 0, 0, 0, 0 }
		};

		// Check end of option list
		//
		if ((short_option = getopt_long (argc, argv, "rltgc:v:wh", 
			long_options, NULL)) == -1) break;

		// Process short option
		//
		switch (short_option)
		{
			case 'l':
				options = options | 1;
				break;
			case 't':
				 options = options | 2;
				break;
			case 'c':
//				options = options | 4;
				compare = strdup(optarg);
				break;
			case 'r':
				options = options | 8;
				break;
			case 'g':
				options = options | 16;
				break;
			case 'w':
				// setting warnings to errors
				//
				PANA_warning_to_error = 1;
				break;
			case 'h':
				display_panalist_usage();
				exit(0);
				break;
			case 'v':
				// setting debug level from verbose
				//
				PANA_debug_level = (int) strtol( optarg, 0, 10);
				break;
			case ':':
				cerr << gettext("panalist command: missing parameter on '");
				cerr << argv[optind] << "'\n";
				exit(1);
				break;
			case '?':
				cerr << gettext("panalist command: extraneous parameter '");
				cerr << argv[optind] << "'\n";
				exit(1);
				break;
			default:
				cerr << gettext("panalist command: unexpected option '");
				cerr << short_option << "' ";
				cerr << gettext("[internal error]") << endl;
				exit(2);
		}
	}

	// Retrieve directories from command-line
	
	// number of arguments
	//
	int nargs = argc - optind;

	if ( panamultilist( nargs, &argv[ optind ], options, compare) != 0)
		return 1;

	// free resources
	//
	if ( compare ) free(compare);

	return 0;
}


