
#include <unistd.h>
#include <getopt.h>
#include <libintl.h>
#include <locale.h>

#include "panacmds.h"


// common options for all commands
//
void display_common_usage()
{
  cout  << gettext("common options:")
<< endl << gettext("   -v level : sets verbose level, 0 for nothing.")
<< endl << gettext("   -w, --warning : consider warnings to be errors and abort command.")
<< endl;
}


// panamove usage
//
void display_panamove_usage()
{
  cout  << gettext("usage:")
<< endl << gettext("   panamove {-h --help}")
<< endl << gettext("   panamove sourceDir/File targetDir")
<< endl << gettext("   panamove source1 ... sourceN targetDir")
<< endl << gettext("   panamove sourceFile targetFile")
<< endl << endl;
display_common_usage();
}


// panamove command
//
int main( int argc, char **argv)
{


	// language initialization
	//
	setlocale( LC_MESSAGES, "");
	bindtextdomain( PACKAGE, PACKAGE_ROOT_DIRECTORY);
	textdomain( PACKAGE);

	// Process command-line options
	//
	while (1)
	{
		int short_option;	// Short option character

		// Long options declaration & short options mappings
		//
		static struct option long_options[] =
		{
			{ "warn", 0, NULL, 'w' },
			{ "help", 0, NULL, 'h' },
			{ 0, 0, 0, 0 }
		};

		// Check end of option list
		//
		if ((short_option = getopt_long (argc, argv, "v:wh", 
			long_options, NULL)) == -1) break;

		// Process short option
		//
		switch (short_option)
		{
			case 'w':
				// setting warnings to errors
				//
				PANA_warning_to_error = 1;
				break;
			case 'h':
				display_panamove_usage();
				exit(0);
				break;
			case 'v':
				// setting debug level from verbose
				//
				PANA_debug_level = (int) strtol( optarg, 0, 10);
				break;
			case ':':
				cerr << gettext("panamove command: missing parameter on '");
				cerr << argv[optind] << "'\n";
				exit(1);
				break;
			case '?':
				cerr << gettext("panamove command: extraneous parameter '");
				cerr << argv[optind] << "'\n";
				exit(1);
				break;
			default:
				cerr << gettext("panamove command: unexpected option '");
				cerr << short_option << "' ";
				cerr << gettext("[internal error]") << endl;
				exit(2);
		}
	}

	// Retrieve source/s and target files from command-line
	
	// number of arguments of (source1...N target)
	//
	int nargs = argc - optind;

	// at least 2 arguments...
	if ( nargs > 1)
	{
		// call panamultimove with source... , target
		//
		if ( panamultimove( nargs-1, &argv[optind], argv[argc-1]) != 0)
		{
			exit(1);
		}
	}
	else // less than 2 arguments
	{
		cerr << gettext("panamove command: illegal number of arguments.") << endl;
		exit(1);
	}

	return 0;
}


