
#include <unistd.h>
#include <getopt.h>
#include <libintl.h>
#include <locale.h>

#include "panacmds.h"


// common options for all commands
//
void display_common_usage()
{
  cout  << gettext("common options:")
<< endl << gettext("   -v level : sets verbose level, 0 for nothing.")
<< endl << gettext("   -w, --warning : consider warnings to be errors and abort command.")
<< endl;
}

 
// pananew usage
// 
void	display_pananew_usage()
{
  cout  << gettext("usage:")
<< endl << gettext("   pananew {-h --help}")
<< endl << gettext("   pananew [-b --base-file basepath] [-c --contents-file contentspath] targetpath")
<< endl << endl;
display_common_usage();
}


// pananew command
//
int main( int argc, char **argv)
{
	char * target = 0;
	char * contents = 0;
	char * base = 0;


	// language initialization
	//
	setlocale( LC_MESSAGES, "");
	bindtextdomain( PACKAGE, PACKAGE_ROOT_DIRECTORY);
	textdomain( PACKAGE);


	// Process command-line options
	//
	while (1)
	{
		int short_option;	// Short option character

		// Long options declaration & short options mappings
		//
		static struct option long_options[] =
		{
			{ "base-file", 1, NULL, 'b' },
			{ "contents-file", 1, NULL, 'c' },
			{ "warning", 0, NULL, 'w' },
			{ "help", 0, NULL, 'h' },
			{ 0, 0, 0, 0 }
		};

		// Check end of option list
		//
		if ((short_option = getopt_long (argc, argv, "b:c:v:wh", 
			long_options, NULL)) == -1) break;

		// Process short option
		//
		switch (short_option)
		{
			case 'b':
				base = strdup(optarg);
				break;
			case 'c':
				contents = strdup(optarg);
				break;
			case 'w':
				// setting warnings to errors
				//
				PANA_warning_to_error = 1;
				break;
			case 'h':
				display_pananew_usage();
				exit(0);
				break;
			case 'v':
				// setting debug level from verbose
				//
				PANA_debug_level = (int) strtol( optarg, 0, 10);
				break;
			case ':':
				cerr << gettext("pananew command: missing parameter on '");
				cerr << argv[optind] << "'\n";
				exit(1);
				break;
			case '?':
				cerr << gettext("pananew command: extraneous parameter '");
				cerr << argv[optind] << "'\n";
				exit(1);
				break;
			default:
				cerr << gettext("pananew command: unexpected option '");
				cerr << short_option << "' ";
				cerr << gettext("[internal error]") << endl;
				exit(2);
		}
	}

	// Retrieve target file from command-line
	//
	if (optind + 1 == argc)
	{
		target = argv[optind];
	}
	else
	{
		cerr << gettext("pananew command: illegal number of arguments.")<< endl;
		exit(1);
	}

	// call pananew fuction
	//
	if ( pananew(target, contents, base) != 0)
	{
//		cerr << gettext("pananew command: internal error") << endl;
		exit(1);
	}

	// free resources
	//
	if ( base != 0) free(base);
	if ( contents != 0) free(contents);

	return 0;
}

